import { Address, TokenPair, Fee, ContractInstantiationInfo } from './core';
import { SmartContract } from './contract';
import { TokenSaleConfig } from './ido';
import { ExecuteResult, SigningCosmWasmClient, CosmWasmClient } from 'secretjs';
export interface Exchange {
    pair: TokenPair;
    address: Address;
}
export interface ExchangeSettings {
    sienna_burner?: Address | undefined;
    sienna_fee: ExchangeFee;
    swap_fee: ExchangeFee;
}
export interface ExchangeFee {
    denom: number;
    nom: number;
}
export declare class Pagination {
    readonly start: number;
    /**
     * Max is 30.
     */
    readonly limit: number;
    constructor(start: number, 
    /**
     * Max is 30.
     */
    limit: number);
}
export interface FactoryConfig {
    exchange_settings: ExchangeSettings;
    ido_contract: ContractInstantiationInfo;
    lp_token_contract: ContractInstantiationInfo;
    pair_contract: ContractInstantiationInfo;
    snip20_contract: ContractInstantiationInfo;
}
export declare class FactoryContract extends SmartContract {
    readonly address: Address;
    readonly signing_client: SigningCosmWasmClient;
    readonly client?: CosmWasmClient | undefined;
    constructor(address: Address, signing_client: SigningCosmWasmClient, client?: CosmWasmClient | undefined);
    create_exchange(pair: TokenPair, fee?: Fee): Promise<ExecuteResult>;
    create_ido(config: TokenSaleConfig, fee?: Fee): Promise<ExecuteResult>;
    set_config(snip20_contract: ContractInstantiationInfo | undefined, lp_token_contract: ContractInstantiationInfo | undefined, pair_contract: ContractInstantiationInfo | undefined, ido_contract: ContractInstantiationInfo | undefined, exchange_settings: ExchangeSettings | undefined, fee?: Fee): Promise<ExecuteResult>;
    get_exchange_address(pair: TokenPair): Promise<Address>;
    list_idos(pagination: Pagination): Promise<Address[]>;
    list_exchanges(pagination: Pagination): Promise<Exchange[]>;
    get_config(): Promise<FactoryConfig>;
}
