"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FactoryContract = exports.Pagination = void 0;
const core_1 = require("./core");
const contract_1 = require("./contract");
const secretjs_1 = require("secretjs");
const base64_1 = require("@waiting/base64");
class Pagination {
    constructor(start, 
    /**
     * Max is 30.
     */
    limit) {
        this.start = start;
        this.limit = limit;
    }
}
exports.Pagination = Pagination;
class FactoryContract extends contract_1.SmartContract {
    constructor(address, signing_client, client) {
        super(address, signing_client, client);
        this.address = address;
        this.signing_client = signing_client;
        this.client = client;
    }
    create_exchange(pair, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                create_exchange: {
                    pair,
                    entropy: create_entropy()
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('750000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    create_ido(config, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                create_ido: {
                    info: config,
                    entropy: create_entropy()
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    set_config(snip20_contract, lp_token_contract, pair_contract, ido_contract, exchange_settings, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                set_config: {
                    snip20_contract,
                    lp_token_contract,
                    pair_contract,
                    ido_contract,
                    exchange_settings
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('150000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    get_exchange_address(pair) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                get_exchange_address: {
                    pair
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.get_exchange_address.address;
        });
    }
    list_idos(pagination) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                list_idos: {
                    pagination
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.list_idos.idos;
        });
    }
    list_exchanges(pagination) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                list_exchanges: {
                    pagination
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.list_exchanges.exchanges;
        });
    }
    get_config() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                get_config: {}
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.config;
        });
    }
}
exports.FactoryContract = FactoryContract;
function create_entropy() {
    const rand = secretjs_1.EnigmaUtils.GenerateNewSeed().toString();
    return base64_1.b64encode(rand);
}
