import { Address, Uint128, Fee, TokenTypeAmount, TokenPairAmount, Decimal, ContractInfo, TokenPair } from './core';
import { SmartContract } from './contract';
import { ExecuteResult, SigningCosmWasmClient, CosmWasmClient } from 'secretjs';
export interface SwapSimulationResponse {
    return_amount: Uint128;
    spread_amount: Uint128;
    commission_amount: Uint128;
}
export interface PairInfo {
    amount_0: Uint128;
    amount_1: Uint128;
    factory: ContractInfo;
    liquidity_token: ContractInfo;
    pair: TokenPair;
    total_liquidity: Uint128;
    contract_version: number;
}
export declare class ExchangeContract extends SmartContract {
    readonly address: Address;
    readonly signing_client: SigningCosmWasmClient;
    readonly client?: CosmWasmClient | undefined;
    constructor(address: Address, signing_client: SigningCosmWasmClient, client?: CosmWasmClient | undefined);
    provide_liquidity(amount: TokenPairAmount, tolerance?: Decimal | null, fee?: Fee): Promise<ExecuteResult>;
    withdraw_liquidity(amount: Uint128, recipient: Address, fee?: Fee): Promise<ExecuteResult>;
    swap(amount: TokenTypeAmount, recipient?: Address | null, expected_return?: Decimal | null, fee?: Fee): Promise<ExecuteResult>;
    get_pair_info(): Promise<PairInfo>;
    simulate_swap(amount: TokenTypeAmount): Promise<SwapSimulationResponse>;
}
