"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExchangeContract = void 0;
const core_1 = require("./core");
const contract_1 = require("./contract");
const snip20_1 = require("./snip20");
class ExchangeContract extends contract_1.SmartContract {
    constructor(address, signing_client, client) {
        super(address, signing_client, client);
        this.address = address;
        this.signing_client = signing_client;
        this.client = client;
    }
    provide_liquidity(amount, tolerance, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                add_liquidity: {
                    deposit: amount,
                    slippage_tolerance: tolerance
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('530000');
            }
            const transfer = core_1.add_native_balance_pair(amount);
            return yield this.signing_client.execute(this.address, msg, undefined, transfer, fee);
        });
    }
    withdraw_liquidity(amount, recipient, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                remove_liquidity: {
                    recipient
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('610000');
            }
            const info = yield this.get_pair_info();
            const snip20 = new snip20_1.Snip20Contract(info.liquidity_token.address, this.signing_client);
            return yield snip20.send(this.address, amount, msg, null, fee);
        });
    }
    swap(amount, recipient, expected_return, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            if (core_1.get_token_type(amount.token) == core_1.TypeOfToken.Native) {
                if (fee === undefined) {
                    fee = core_1.create_fee('280000');
                }
                const msg = {
                    swap: {
                        offer: amount,
                        to: recipient,
                        expected_return
                    }
                };
                const transfer = core_1.add_native_balance(amount);
                return yield this.signing_client.execute(this.address, msg, undefined, transfer, fee);
            }
            if (fee === undefined) {
                fee = core_1.create_fee('530000');
            }
            const msg = {
                swap: {
                    to: recipient,
                    expected_return
                }
            };
            const token_addr = amount.token.custom_token.contract_addr;
            const snip20 = new snip20_1.Snip20Contract(token_addr, this.signing_client);
            return yield snip20.send(this.address, amount.amount, msg, null, fee);
        });
    }
    get_pair_info() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = 'pair_info'; //yeah...
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.pair_info;
        });
    }
    simulate_swap(amount) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                swap_simulation: {
                    offer: amount
                }
            };
            return yield this.query_client().queryContractSmart(this.address, msg);
        });
    }
}
exports.ExchangeContract = ExchangeContract;
