"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdoContract = exports.TokenSaleConfig = void 0;
const core_1 = require("./core");
const contract_1 = require("./contract");
const snip20_1 = require("./snip20");
class TokenSaleConfig {
    constructor(
    /**
     * The token that will be used to buy the SNIP20.
     */
    input_token, 
    /**
     * The total amount that each participant is allowed to buy.
     */
    max_allocation, 
    /**
     * The minimum amount that each participant is allowed to buy.
     */
    min_allocation, 
    /**
     * The maximum number of participants allowed.
     */
    max_seats, 
    /**
     * The price for a single token.
     */
    rate, sold_token, 
    /**
     * The addresses that are eligible to participate in the sale.
     */
    whitelist) {
        this.input_token = input_token;
        this.max_allocation = max_allocation;
        this.min_allocation = min_allocation;
        this.max_seats = max_seats;
        this.rate = rate;
        this.sold_token = sold_token;
        this.whitelist = whitelist;
    }
}
exports.TokenSaleConfig = TokenSaleConfig;
class IdoContract extends contract_1.SmartContract {
    constructor(address, signing_client, client) {
        super(address, signing_client, client);
        this.address = address;
        this.signing_client = signing_client;
        this.client = client;
    }
    swap(amount, recipient, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.input_token === undefined) {
                const info = yield this.get_sale_info();
                this.input_token = info.input_token;
            }
            if (core_1.get_token_type(this.input_token) == core_1.TypeOfToken.Native) {
                if (fee === undefined) {
                    fee = core_1.create_fee('280000');
                }
                const msg = {
                    swap: {
                        amount,
                        recipient,
                    }
                };
                return yield this.signing_client.execute(this.address, msg, undefined, [core_1.create_coin(amount)], fee);
            }
            if (fee === undefined) {
                fee = core_1.create_fee('3500000');
            }
            const msg = {
                swap: {
                    recipient
                }
            };
            const token_addr = this.input_token.custom_token.contract_addr;
            const snip20 = new snip20_1.Snip20Contract(token_addr, this.signing_client);
            return yield snip20.send(this.address, amount, msg, null, fee);
        });
    }
    refund(recipient, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                admin_refund: {
                    address: recipient
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('3000000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    claim(recipient, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                admin_claim: {
                    address: recipient
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('3000000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    add_addresses(addresses, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                admin_add_addresses: {
                    addresses
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('3000000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    activate(sale_amount, end_time, start_time, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            if (fee === undefined) {
                fee = core_1.create_fee('3000000');
            }
            const msg = {
                activate: {
                    end_time,
                    start_time
                }
            };
            const info = yield this.get_sale_info();
            const snip20 = new snip20_1.Snip20Contract(info.sold_token.address, this.signing_client);
            return yield snip20.send(this.address, sale_amount, msg, null, fee);
        });
    }
    get_balance(key, address) {
        return __awaiter(this, void 0, void 0, function* () {
            // It's the same interface as SNIP20
            const snip20 = new snip20_1.Snip20Contract(this.address, this.signing_client, this.client);
            return yield snip20.get_balance(key, address);
        });
    }
    get_sale_info() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = 'sale_info';
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.sale_info;
        });
    }
    get_sale_status() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = 'sale_status';
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.status;
        });
    }
}
exports.IdoContract = IdoContract;
