"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RewardsContract = void 0;
const core_1 = require("./core");
const contract_1 = require("./contract");
class RewardsContract extends contract_1.SmartContract {
    constructor(address, signing_client, client) {
        super(address, signing_client, client);
        this.address = address;
        this.signing_client = signing_client;
        this.client = client;
    }
    claim(fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                claim: {}
            };
            if (fee === undefined) {
                fee = core_1.create_fee('300000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    lock_tokens(amount, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                lock: {
                    amount
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('280000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    retrieve_tokens(amount, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                retrieve: {
                    amount
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('260000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    get_pool(at) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                pool_info: {
                    at
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.pool_info;
        });
    }
    get_account(address, key, at) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                user_info: {
                    address,
                    key,
                    at
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.user_info;
        });
    }
}
exports.RewardsContract = RewardsContract;
