import { Address, Uint128, Fee, ViewingKey } from './core';
import { SmartContract } from './contract';
import { ExecuteResult, SigningCosmWasmClient, CosmWasmClient } from 'secretjs';
export interface TokenInfo {
    name: string;
    symbol: string;
    decimals: number;
    total_supply?: Uint128 | null;
}
export interface Allowance {
    spender: Address;
    owner: Address;
    allowance: Uint128;
    expiration?: number | null;
}
export interface ExchangeRate {
    rate: Uint128;
    denom: string;
}
export declare class Snip20Contract extends SmartContract {
    readonly address: Address;
    readonly signing_client: SigningCosmWasmClient;
    readonly client?: CosmWasmClient | undefined;
    constructor(address: Address, signing_client: SigningCosmWasmClient, client?: CosmWasmClient | undefined);
    increase_allowance(spender: Address, amount: Uint128, expiration?: number | null, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
    get_allowance(owner: Address, spender: Address, key: ViewingKey): Promise<Allowance>;
    get_balance(key: ViewingKey, address?: Address): Promise<Uint128>;
    get_token_info(): Promise<TokenInfo>;
    get_exchange_rate(): Promise<ExchangeRate>;
    set_viewing_key(key: ViewingKey, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
    deposit(amount: Uint128, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
    transfer(recipient: Address, amount: Uint128, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
    send(recipient: Address, amount: Uint128, msg?: object | null, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
    mint(recipient: Address, amount: Uint128, padding?: string | null, fee?: Fee): Promise<ExecuteResult>;
}
