"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Snip20Contract = void 0;
const core_1 = require("./core");
const contract_1 = require("./contract");
class Snip20Contract extends contract_1.SmartContract {
    constructor(address, signing_client, client) {
        super(address, signing_client, client);
        this.address = address;
        this.signing_client = signing_client;
        this.client = client;
    }
    increase_allowance(spender, amount, expiration, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                increase_allowance: {
                    spender,
                    amount,
                    expiration,
                    padding
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    get_allowance(owner, spender, key) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                allowance: {
                    owner,
                    spender,
                    key
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.allowance;
        });
    }
    get_balance(key, address) {
        return __awaiter(this, void 0, void 0, function* () {
            if (address === undefined) {
                address = this.signing_client.senderAddress;
            }
            const msg = {
                balance: {
                    address,
                    key
                }
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.balance.amount;
        });
    }
    get_token_info() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                token_info: {}
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.token_info;
        });
    }
    get_exchange_rate() {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                exchange_rate: {}
            };
            const result = yield this.query_client().queryContractSmart(this.address, msg);
            return result.exchange_rate;
        });
    }
    set_viewing_key(key, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                set_viewing_key: {
                    key,
                    padding
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    deposit(amount, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                deposit: {
                    padding
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            const transfer = [core_1.create_coin(amount)];
            return yield this.signing_client.execute(this.address, msg, undefined, transfer, fee);
        });
    }
    transfer(recipient, amount, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                transfer: {
                    recipient,
                    amount,
                    padding
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
    send(recipient, amount, msg, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const message = {
                send: {
                    recipient,
                    amount,
                    padding,
                    msg: msg ? core_1.create_base64_msg(msg) : null
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, message, undefined, undefined, fee);
        });
    }
    mint(recipient, amount, padding, fee) {
        return __awaiter(this, void 0, void 0, function* () {
            const msg = {
                mint: {
                    recipient,
                    amount,
                    padding
                }
            };
            if (fee === undefined) {
                fee = core_1.create_fee('200000');
            }
            return yield this.signing_client.execute(this.address, msg, undefined, undefined, fee);
        });
    }
}
exports.Snip20Contract = Snip20Contract;
